@@ -1,7 +1,6 @@
 use crate::helpers;
-use libmacchina::extra::list_dir_entries;
 use owo_colors::OwoColorize;
-use std::path::PathBuf;
+use std::path::{Path, PathBuf};
 
 fn library_locations() -> Vec<PathBuf> {
     let mut locations = vec![];
@@ -25,15 +24,28 @@ pub fn get_debug() {
     );
 }
 
+pub fn get_entries(path: &Path) -> Option<Vec<PathBuf>> {
+    if let Ok(dir) = std::fs::read_dir(path) {
+        let mut entries: Vec<PathBuf> = Vec::new();
+        dir.flatten().for_each(|x| entries.push(x.path()));
+        Some(entries)
+    } else {
+        None
+    }
+}
+
 fn check_libdbus() {
     let base_locations = library_locations();
 
-    let found = base_locations.iter().find(|&x| {
-        let libraries = list_dir_entries(x);
-        libraries.iter().any(|l| {
-            let file = helpers::basename(l.to_str().unwrap_or_default());
-            file.starts_with("libdbus-") && file.ends_with("so")
-        })
+    let found = base_locations.iter().find(|&dir| {
+        if let Some(libraries) = get_entries(dir) {
+            return libraries.iter().any(|l| {
+                let file = helpers::basename(l.to_str().unwrap_or_default());
+                file.starts_with("libdbus-") && file.ends_with("so")
+            });
+        };
+
+        false
     });
 
     if found.is_some() {
